"""
Helper functions for ANIAnimator
"""

from __future__ import absolute_import
import os
import re
import mogli

ANI_PATTERN = re.compile(
    r"([ \t]+[0-9]+\n" +
    r".+\n" +
    r"(\S+[ \t]+-?[0-9]+\.[0-9]+[ \t]+-?[0-9]+\.[0-9]+[ \t]+-?[0-9]+\.[0-9]+\n)+)"
)


def split_ani(anifile):
    """Split ANI files to xyz"""
    with open(anifile, encoding="utf-8") as file:
        print(f"Opening {anifile}")
        ani = file.read()
        file.close()
        return ANI_PATTERN.findall(ani)


def write_xyzs(xyzs):
    """Write xyz files"""
    xyzfiles = []
    print("Making directory ANIAnimator_temp")
    if not os.path.exists("ANIAnimator_temp"):
        os.mkdir("ANIAnimator_temp")
    for i, xyz in enumerate(xyzs):
        with open(f"ANIAnimator_temp{os.sep}{i}.xyz", "w", encoding="utf-8") as file:
            print(f"Creating xyz files ({i + 1}/{len(xyzs)})", end="\r")
            file.write(xyz[0])
            file.close()
        xyzfiles.append(f"ANIAnimator_temp{os.sep}{i}.xyz")
    return xyzfiles


def write_pngs(xyzfiles, width=None, height=None, bonds_param=None, camera=None):
    """Write png files"""
    if width is None:
        width = 1920
    if height is None:
        height = 1080
    if bonds_param is None:
        bonds_param = 1.3
    pngfiles = []
    print()
    for i, xyzfile in enumerate(xyzfiles):
        molecules = mogli.read(xyzfile)
        print(f"Creating png files ({i + 1}/{len(xyzfiles)})", end="\r")
        mogli.export(
            molecules[0],
            f"ANIAnimator_temp{os.sep}{i}.png",
            width=width,
            height=height,
            bonds_param=bonds_param,
            camera=camera
        )
        pngfiles.append(f"ANIAnimator_temp{os.sep}{i}.png")
    return pngfiles



"""
ANIAnimator makes the GIF file from a given chemical ANI file
"""
from __future__ import absolute_import

__title__ = "ANIAnimator"
__author__ = "Eftal Gezer"
__license__ = "GNU GPL v3"
__copyright__ = "Copyright 2022, Eftal Gezer"
__version__ = "0.1.0"

from .core import animate



"""
Setup file for ANIAnimator
"""
from __future__ import absolute_import
import pathlib
from setuptools import setup


HERE = pathlib.Path(__file__).parent.resolve()

LONG_DESCRIPTION = (HERE / "README.md").read_text(encoding="utf-8")

setup(
    name="ANIAnimator",
    version="0.1.0",
    description="ANIAnimator makes the GIF file from a given chemical ANI file",
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/markdown",
    url="https://github.com/eftalgezer/ANIAnimator",
    author="Eftal Gezer",
    author_email="eftal.gezer@astrobiyoloji.org",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Intended Audience :: Education",
        "Intended Audience :: Science/Research",
        "Topic :: Education",
        "Topic :: Multimedia :: Graphics :: Graphics Conversion",
        "Topic :: Scientific/Engineering",
        "Topic :: Scientific/Engineering :: Bio-Informatics",
        "Topic :: Scientific/Engineering :: Chemistry",
        "Topic :: Scientific/Engineering :: Physics",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: POSIX :: Linux",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3 :: Only",
    ],
    keywords="ANI, GIF, animation, molecular calculations, chemistry, physics," +
    "ANI to GIF converter",
    packages=["ANIAnimator"],
    install_requires=[
        "mogli",
        "pillow",
        ],
    project_urls={
        "Bug Reports": "https://github.com/eftalgezer/ANIAnimator/issues",
        "Source": "https://github.com/eftalgezer/ANIAnimator/",
        "Blog": "https://beyondthearistotelian.blogspot.com/search/label/ANIAnimator",
        "Developer": "https://www.eftalgezer.com/",
    },
)
